| dropTipPartial | R Documentation |
Wrapper for the ape function drop.tip that preserves the number of nodes affecting each branch. For use with the psi and multipsi models.
dropTipPartial(phy, tip)
phy |
Phylogenetic tree in |
tip |
A vector of mode numeric or character specifying the tips to delete, to be passed to |
Phylogenetic tree in phylo format, with an added element Shid, a vector of numbers of observed but "missing" speciation events per branch, in the same order as the branches in the phylo object
Travis Ingram
Ingram, T. 2011. Speciation along a depth gradient in a marine adaptive radiation. Proc. R. Soc. B 278: 613-618.
transformPhylo.ML
## Read in phylogeny and data from Thomas et al. (2009)
data(anolis.tree)
data(anolis.data)
## identify tips to drop
tips.to.go <- anolis.tree$tip.label[1:30]
dropTipPartial(phy=anolis.tree, tip=tips.to.go)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.