sympatric.data: Pairwise sympatry matrix for finch species

sympatric.dataR Documentation

Pairwise sympatry matrix for finch species

Description

A 13 by 13 numeric matrix indicating sympatry between finch species included in this package.

Usage

data(finches)

Format

A numeric matrix with dimensions 13 x 13. Row and column names are species labels corresponding to 'finch.data' and 'finch.tree'. Entries are integers (typically 1 for sympatry, 0 for absence of sympatry).

Details

This matrix provides pairwise sympatry information (presence/absence) among the finch species supplied with the package and can be used with functions that require sympatry/allopatry matrices.

References

Clarke M, Thomas GH, Freckleton RP. 2017. Trait evolution in adaptive radiations: modelling and measuring interspecific competition on phylogenies. The American Naturalist. 189, 121-137.

Examples

data(finches)
head(sympatric.data)

motmot documentation built on April 27, 2026, 9:08 a.m.