| sympatric.data | R Documentation |
A 13 by 13 numeric matrix indicating sympatry between finch species included in this package.
data(finches)
A numeric matrix with dimensions 13 x 13. Row and column names are species labels corresponding to 'finch.data' and 'finch.tree'. Entries are integers (typically 1 for sympatry, 0 for absence of sympatry).
This matrix provides pairwise sympatry information (presence/absence) among the finch species supplied with the package and can be used with functions that require sympatry/allopatry matrices.
Clarke M, Thomas GH, Freckleton RP. 2017. Trait evolution in adaptive radiations: modelling and measuring interspecific competition on phylogenies. The American Naturalist. 189, 121-137.
data(finches)
head(sympatric.data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.